@@ -37,7 +37,7 @@ def toBytes(s):
     return s if six.PY2 else s.encode()
     
 HEALTHCHECK_URL = "https://healthchecks.nuwainfo.com"
-HEALTHCHECK_API_KEY = "p8w-S3Au7KBw2bRUAgtyenTziz-zdWyl"
+HEALTHCHECK_API_KEY = getattr(settings, 'HEALTHCHECK_API_KEY', "p8w-S3Au7KBw2bRUAgtyenTziz-zdWyl")
 
 class Command(BaseCommand):
     
@@ -59,7 +59,7 @@ class Command(BaseCommand):
         sysStr = platform.system()
         if sysStr == "Linux":
             # healthcheck
-            checkName = "%s %s" % (getattr(settings, "APP_NAME", "[No App Name]"), command)
+            checkName = "%s %s" % (getattr(settings, "APP_NAME", "[Unknown]"), command)
             headers = {
                 "X-Api-Key": HEALTHCHECK_API_KEY,
             }
@@ -71,7 +71,7 @@ class Command(BaseCommand):
             if not checkName in [check.get("name") for check in data.get("checks", []) if check.get("name")]:
                 postData = {
                     "name": checkName,
-                    "tags": "Crontask",
+                    "tags": "cron",
                     "timeout": 86400, # 一天
                     "grace": 3600, # 一小時
                 }
@@ -120,9 +120,11 @@ class Command(BaseCommand):
             
             with open("%s.sh" % jobName, 'w') as f:
                 f.write(shell)
-                
-            temp = get_template("deploy/Crontask.sh")
-            crontask = temp.render(c).replace("\r\n", "\n")
+            
+            # Crontask.sh
+            response = requests.get(
+                "https://github.com/nuwainfo/crontask/raw/Iuno/Crontask.sh")
+            crontask = response.text
             if not os.path.exists("cron"):
                 os.mkdir("cron")
             with open("cron/Crontask.sh", 'w', encoding="utf8") as f:
