@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettingsTest.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: AttachSettingsTest.py 12398 2020-07-16 10:04:42Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2020-07-16 19:04:42 +0900 (週四, 16 七月 2020) $
+# $Revision: 12398 $
 
 import os
 from django.test import TestCase
@@ -34,7 +34,7 @@ class TestAttachSettings(TestCase):
                 'django.contrib.staticfiles',
             ),
 
-            "MIDDLEWARE_CLASSES": (
+            "MIDDLEWARE": (
                 'django.contrib.sessions.middleware.SessionMiddleware',
                 'django.middleware.common.CommonMiddleware',
                 'django.middleware.csrf.CsrfViewMiddleware',
@@ -90,28 +90,51 @@ class TestAttachSettings(TestCase):
                 'django.contrib.staticfiles', 
                 'django.contrib.sites', 
                 'django.contrib.flatpages', 
-                'compressor', 'widget_tweaks', 
-                'oscar', 'oscar.apps.analytics', 
-                'oscar.apps.checkout', 'oscar.apps.address', 
-                'oscar.apps.shipping', 'oscar.apps.catalogue', 
-                'oscar.apps.catalogue.reviews', 'oscar.apps.partner', 
-                'oscar.apps.basket', 'oscar.apps.payment', 'oscar.apps.offer', 
-                'oscar.apps.order', 'oscar.apps.customer', 
-                'oscar.apps.promotions', 'oscar.apps.search', 
-                'oscar.apps.voucher', 'oscar.apps.wishlists', 
-                'oscar.apps.dashboard', 'oscar.apps.dashboard.reports', 
-                'oscar.apps.dashboard.users', 'oscar.apps.dashboard.orders', 
-                'oscar.apps.dashboard.promotions', 
+                'django.contrib.humanize', 
+                'widget_tweaks', 
+                'sorl.thumbnail', 
+                'oscar', 
+                'oscar.apps.analytics', 
+                'oscar.apps.checkout', 
+                'oscar.apps.address', 
+                'oscar.apps.shipping', 
+                'oscar.apps.catalogue', 
+                'oscar.apps.catalogue.reviews', 
+                'oscar.apps.partner', 
+                'oscar.apps.basket', 
+                'oscar.apps.payment', 
+                'oscar.apps.offer', 
+                'oscar.apps.order', 
+                'oscar.apps.customer', 
+                'oscar.apps.search', 
+                'oscar.apps.voucher', 
+                'oscar.apps.wishlists', 
+                'oscar.apps.dashboard', 
+                'oscar.apps.dashboard.reports', 
+                'oscar.apps.dashboard.users', 
+                'oscar.apps.dashboard.orders', 
                 'oscar.apps.dashboard.catalogue', 
-                'oscar.apps.dashboard.offers', 'oscar.apps.dashboard.partners',
-                'oscar.apps.dashboard.pages', 'oscar.apps.dashboard.ranges', 
-                'oscar.apps.dashboard.reviews', 'oscar.apps.dashboard.vouchers', 
+                'oscar.apps.dashboard.offers', 
+                'oscar.apps.dashboard.partners', 
+                'oscar.apps.dashboard.pages', 
+                'oscar.apps.dashboard.ranges', 
+                'oscar.apps.dashboard.reviews', 
+                'oscar.apps.dashboard.vouchers', 
                 'oscar.apps.dashboard.communications', 
-                'oscar.apps.dashboard.shipping', 'haystack', 'treebeard', 
-                'sorl.thumbnail', 'django_tables2'],
+                'oscar.apps.dashboard.shipping', 
+                'haystack', 
+                'treebeard', 
+                'django_tables2', 
+                'Iuno.shop', 
+                'Iuno.shop.promotions', 
+                'Iuno.shop.dashboard_promotions', 
+                'ckeditor', 
+                'ckeditor_uploader'
+            ],
         }
-        self.assertEqual(settingsContent['INSTALLED_APPS'],
-                         installedAppsSettings['INSTALLED_APPS'])
+        
+        self.assertListEqual(settingsContent['INSTALLED_APPS'],
+                             installedAppsSettings['INSTALLED_APPS'])
 
 if __name__ == "__main__":
     testAttachSettings = TestAttachSettings()
